@@ -7,7 +7,7 @@ data_dir <- base_path
 base_path <- tempdir()
 data_dir <- "."
 
-dev <- TRUE
+dev <- FALSE
 
 
 test_that("user1: demo table works.", {
@@ -628,7 +628,6 @@ test_that("user6: listings with page break works as expected.", {
     
     expect_equal(length(lns), res$pages * res$line_count)
     
-    
     res <- write_report(rpt, output_type = "RTF")
     expect_equal(file.exists(res$modified_path), TRUE)
     
@@ -1033,6 +1032,3 @@ test_that("Title header alignment works as expected.", {
   
 })
 
-
-
-  
